@@ -1,26 +1,18 @@
 /* Unicode character case mappings.
-   Copyright (C) 2002, 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2009-2024 Free Software Foundation, Inc.
 
-   This file is free software.
-   It is dual-licensed under "the GNU LGPLv3+ or the GNU GPLv2+".
-   You can redistribute it and/or modify it under either
-     - the terms of the GNU Lesser General Public License as published
-       by the Free Software Foundation, either version 3, or (at your
-       option) any later version, or
-     - the terms of the GNU General Public License as published by the
-       Free Software Foundation; either version 2, or (at your option)
-       any later version, or
-     - the same dual license "the GNU LGPLv3+ or the GNU GPLv2+".
+   This file is free software: you can redistribute it and/or modify
+   it under the terms of the GNU Lesser General Public License as
+   published by the Free Software Foundation; either version 2.1 of the
+   License, or (at your option) any later version.
 
    This file is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Lesser General Public License and the GNU General Public License
-   for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License and of the GNU General Public License along with this
-   program.  If not, see <https://www.gnu.org/licenses/>.  */
+   You should have received a copy of the GNU Lesser General Public License
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #ifndef _UNICASE_H
 #define _UNICASE_H
@@ -36,6 +28,12 @@
 /* Get uninorm_t.  */
 #include "uninorm.h"
 
+#if @HAVE_UNISTRING_WOE32DLL_H@
+# include <unistring/woe32dll.h>
+#else
+# define LIBUNISTRING_DLL_VARIABLE
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -155,7 +153,7 @@ typedef struct casing_prefix_context
         }
         casing_prefix_context_t;
 /* The case-mapping context of the empty prefix string.  */
-extern LIBUNISTRING_DLL_VARIABLE const casing_prefix_context_t unicase_empty_prefix_context;
+extern @GNULIB_UNICASE_EMPTY_PREFIX_CONTEXT_DLL_VARIABLE@ const casing_prefix_context_t unicase_empty_prefix_context;
 /* Return the case-mapping context of a given prefix string.  */
 extern casing_prefix_context_t
        u8_casing_prefix_context (const uint8_t *s, size_t n);
@@ -184,7 +182,7 @@ typedef struct casing_suffix_context
         }
         casing_suffix_context_t;
 /* The case-mapping context of the empty suffix string.  */
-extern LIBUNISTRING_DLL_VARIABLE const casing_suffix_context_t unicase_empty_suffix_context;
+extern @GNULIB_UNICASE_EMPTY_SUFFIX_CONTEXT_DLL_VARIABLE@ const casing_suffix_context_t unicase_empty_suffix_context;
 /* Return the case-mapping context of a given suffix string.  */
 extern casing_suffix_context_t
        u8_casing_suffix_context (const uint8_t *s, size_t n);
