@@ -1,9 +1,9 @@
 /* Next grapheme cluster length test.
-   Copyright (C) 2010-2018 Free Software Foundation, Inc.
+   Copyright (C) 2010-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU Lesser General Public License as published
-   by the Free Software Foundation; either version 3 of the License, or
+   by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -57,11 +57,12 @@ test_u32_grapheme_next (size_t len, ...)
       if (next == NULL)
         fputs ("u32_grapheme_next returned NULL", stderr);
       else
-        fprintf (stderr, "u32_grapheme_next skipped %zu units", next - s);
+        fprintf (stderr, "u32_grapheme_next skipped %tu units", next - s);
       fprintf (stderr, ", expected %zu:\n", len);
       for (i = 0; i < n; i++)
         fprintf (stderr, " %04x", s[i]);
       putc ('\n', stderr);
+      fflush (stderr);
       abort ();
     }
 }
