@@ -1,9 +1,9 @@
 /* Grapheme cluster break function test.
-   Copyright (C) 2010-2022 Free Software Foundation, Inc.
+   Copyright (C) 2010-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU Lesser General Public License as published
-   by the Free Software Foundation; either version 3 of the License, or
+   by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -21,7 +21,6 @@
 /* Specification. */
 #include <unigbrk.h>
 
-#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -31,7 +30,6 @@
 const char *
 graphemebreakproperty_to_string (int gbp)
 {
-  printf ("%d\n", gbp);
   switch (gbp)
     {
 #define CASE(VALUE) case GBP_##VALUE: return #VALUE;
@@ -90,6 +88,9 @@ main (int argc, char *argv[])
       const char *p;
       ucs4_t prev;
       int last_char_prop;
+      bool incb_consonant_extended;
+      bool incb_consonant_extended_linker;
+      bool incb_consonant_extended_linker_extended;
       bool emoji_modifier_sequence;
       bool emoji_modifier_sequence_before_last_char;
       size_t ri_count;
@@ -103,6 +104,9 @@ main (int argc, char *argv[])
         continue;
 
       last_char_prop = -1;
+      incb_consonant_extended = false;
+      incb_consonant_extended_linker = false;
+      incb_consonant_extended_linker_extended = false;
       emoji_modifier_sequence = false;
       emoji_modifier_sequence_before_last_char = false;
       ri_count = 0;
@@ -151,10 +155,17 @@ main (int argc, char *argv[])
               next = next_int;
             }
 
+          int incb = uc_indic_conjunct_break (next);
+
           /* Skip unsupported rules involving 3 or more characters.  */
-          if (last_char_prop == GBP_ZWJ
-              && emoji_modifier_sequence_before_last_char
-              && uc_is_property_extended_pictographic (next))
+          if (incb_consonant_extended_linker_extended
+              && incb == UC_INDIC_CONJUNCT_BREAK_CONSONANT)
+            fprintf (stderr, "%s:%d: skipping GB9c: should join U+%04X "
+                     "and U+%04X\n",
+                     filename, lineno, prev, next);
+          else if (last_char_prop == GBP_ZWJ
+                   && emoji_modifier_sequence_before_last_char
+                   && uc_is_property_extended_pictographic (next))
             {
               int prev_gbp = uc_graphemeclusterbreak_property (prev);
               int next_gbp = uc_graphemeclusterbreak_property (next);
@@ -191,6 +202,17 @@ main (int argc, char *argv[])
           p += strspn (p, " \t\r\n");
           prev = next;
 
+          incb_consonant_extended_linker =
+            incb_consonant_extended && incb == UC_INDIC_CONJUNCT_BREAK_LINKER;
+          incb_consonant_extended_linker_extended =
+            (incb_consonant_extended_linker
+             || (incb_consonant_extended_linker_extended
+                 && incb >= UC_INDIC_CONJUNCT_BREAK_LINKER));
+          incb_consonant_extended =
+            (incb == UC_INDIC_CONJUNCT_BREAK_CONSONANT
+             || (incb_consonant_extended
+                 && incb >= UC_INDIC_CONJUNCT_BREAK_LINKER));
+
           emoji_modifier_sequence_before_last_char = emoji_modifier_sequence;
           emoji_modifier_sequence =
             (emoji_modifier_sequence
